@@ -1,6 +1,7 @@
 """
     item 失败回收中间件
 """
+import json
 from palp import settings
 from palp.pipeline.pipeline_base import Pipeline
 
@@ -16,8 +17,8 @@ class ItemRecyclePipeline(Pipeline):
         """
         from palp.conn import redis_conn
 
-        redis_conn.sadd(settings.REDIS_KEY_QUEUE_BAD_ITEM, {
+        redis_conn.sadd(settings.REDIS_KEY_QUEUE_BAD_ITEM, json.dumps({
             'module': item.__class__.__module__,  # 引用自哪里
             'init': item.__class__.__name__,  # 引用的模块名
             'data': item.to_json()
-        })
+        }))
